==> msmtp-scripts-1.2.4.tar.gz: msmtp-scripts-1.2.4/tests/scripts/t00100-shellcheck.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

scriptlist="src/usr/bin/msmtpq-ng src/usr/bin/msmtpq-ng-queue src/usr/sbin/msmtpq-ng-mta src/usr/sbin/msmtpq-ng-queue-mta"

scver="$(shellcheck -V 2>&1|grep version:)"

case $scver in
"version: 0.3."*)
	export ancientsc=true
	for script in $scriptlist; do
		if ! shellcheck -e SC1072,SC1073,SC1009 $script; then
			echo "FAIL: Linting (shellcheck) fails for $script"
			exit 3
		else
			echo "PASS: Linting (shellcheck) succeeds for $script"
			fi
	done
	;;
*)
	export ancientsc=false
	for script in $scriptlist; do
		if ! shellcheck -x ./tmp/msmtpq-ng.rc $script; then
			echo "FAIL: Linting (shellcheck) fails for $script"
			exit 3
		else
			echo "PASS: Linting (shellcheck) succeeds for $script"
		fi
	done
	;;
esac

exit 0

==> msmtp-scripts-1.2.5.1.tar.gz: msmtp-scripts-1.2.5.1/tests/scripts/t00100-shellcheck.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

scriptlist="src/usr/bin/msmtpq-ng src/usr/bin/msmtpq-ng-queue src/usr/sbin/msmtpq-ng-mta src/usr/sbin/msmtpq-ng-queue-mta"

scver="$(shellcheck -V 2>&1|grep version:)"

case $scver in
"version: 0.3."*)
	export ancientsc=true
	for script in $scriptlist; do
		if ! shellcheck -e SC1072,SC1073,SC1009 "$script"; then
			echo "FAIL: Linting (shellcheck) fails for $script"
			exit 3
		else
			echo "PASS: Linting (shellcheck) succeeds for $script"
			fi
	done
	;;
*)
	export ancientsc=false
	for script in $scriptlist; do
		if ! shellcheck -x ./tmp/msmtpq-ng.rc "$script"; then
			echo "FAIL: Linting (shellcheck) fails for $script"
			exit 3
		else
			echo "PASS: Linting (shellcheck) succeeds for $script"
		fi
	done
	;;
esac

exit 0
